@@ -389,49 +389,112 @@ class ContractRedemption:
     naive_end_price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch
     redemption_type: RedemptionType
 
-    @property
-    def clamped_end_price_oracleUnits_per_bch(self) -> ScriptPriceInOracleUnitsPerBch:
-        return max(self.naive_end_price_oracleUnits_per_bch, self.base_funding.base_proposal.long_liquidation_price_oracleUnits_per_bch)
-
-    @property
-    def total_payout_sats(self) -> UtxoSats:
-        # Note: This can be different from total input in the case of liquidation where dust protection is pulled in from outside the contract
-        return UtxoSats(self.hedge_payout_sats + self.long_payout_sats)
-
-    @property
-    def hedge_payout_sats(self) -> UtxoSats:
+    ###############
+    # Parameterized Payout Values
+    ###############
+    @cached_property
+    def _payout_sats_lookup(self) -> dict[(Role | None, Side | None), UtxoSats | None]:
+        # Hedge payout sats is the payout side of the fundamental definition of an AnyHedge contract
         # Note that due to dust safety in the contract, the total actual payout can be greater than total inputs.
         # In reality, the extra dust is covered by an amount sitting on the contract that the contract is not aware of.
         # Use divmod (instead of //) to make it crystal clear this represents integer division of the contract.
         unsafe_hedge_payout_sats, _ = divmod(self.base_funding.base_proposal.nominal_oracleUnits_x_satsPerBch, self.clamped_end_price_oracleUnits_per_bch)
-        safe_hedge_payout_sats = max(DUST, unsafe_hedge_payout_sats)
-        return UtxoSats(safe_hedge_payout_sats)
+        hedge_payout_sats = UtxoSats(max(DUST, unsafe_hedge_payout_sats))
+
+        # Long Payout Sats
+        unsafe_long_payout_sats = self.base_funding.base_proposal.total_input_sats - hedge_payout_sats
+        long_payout_sats = UtxoSats(max(DUST, unsafe_long_payout_sats))
+
+        # Total payout sats is just the combination of hedge and long
+        # Note: This can be different from total input in the case of liquidation where dust protection is pulled in from outside the contract
+        # Any extra dust is covered by an amount sitting on the contract that the contract is not aware of.
+        total_payout_sats = UtxoSats(hedge_payout_sats + long_payout_sats)
+
+        # visual shortcut for the maker/taker sides
+        maker_side = self.base_funding.base_proposal.maker_side
+        taker_side = self.base_funding.base_proposal.taker_side
+
+        return {
+            (None,       None):       total_payout_sats,
+            (None,       Side.HEDGE): hedge_payout_sats,
+            (None,       Side.LONG):  long_payout_sats,
+            (Role.MAKER, None):       hedge_payout_sats if maker_side == Side.HEDGE else long_payout_sats,
+            (Role.MAKER, Side.HEDGE): hedge_payout_sats if maker_side == Side.HEDGE else None,
+            (Role.MAKER, Side.LONG):  long_payout_sats  if maker_side == Side.LONG  else None,
+            (Role.TAKER, None):       hedge_payout_sats if taker_side == Side.HEDGE else long_payout_sats,
+            (Role.TAKER, Side.HEDGE): hedge_payout_sats if taker_side == Side.HEDGE else None,
+            (Role.TAKER, Side.LONG):  long_payout_sats  if taker_side == Side.LONG  else None,
+        }
+
+    def payout_sats(self, role: Role | None = None, side: Side | None = None) -> UtxoSats:
+        key = (role, side)
+        value = self._payout_sats_lookup[key]
+        if value is None:
+            raise ValueError(f'mismatch of role and side query ({key}) with actual contract roles (maker={self.base_funding.base_proposal.maker_side})')
+        return value
+
+    def payout_oracleUnits(self, role: Role | None = None, side: Side | None = None) -> OracleUnit:
+        unit = self.base_funding.base_proposal.oracle_unit_cls
+        bch = self.payout_sats(side=side, role=role).bch
+        # NOTE: using actual end price, not clamped, to determine unit value including any potential slippage
+        return unit(bch * float(self.naive_end_price_oracleUnits_per_bch))
+
+    ###############
+    # Derivative values
+    ###############
+    @property
+    def clamped_end_price_oracleUnits_per_bch(self) -> ScriptPriceInOracleUnitsPerBch:
+        return max(self.naive_end_price_oracleUnits_per_bch, self.base_funding.base_proposal.long_liquidation_price_oracleUnits_per_bch)
+
+    ###############
+    # Property access to payout sats
+    ###############
+    @property
+    def total_payout_sats(self) -> UtxoSats:
+        return self.payout_sats()
+
+    @property
+    def hedge_payout_sats(self) -> UtxoSats:
+        return self.payout_sats(side=Side.HEDGE)
 
     @property
     def long_payout_sats(self) -> UtxoSats:
-        # Note that due to dust safety in the contract, the total actual payout can be greater than total inputs.
-        # In reality, the extra dust is covered by an amount sitting on the contract that the contract is not aware of.
-        unsafe_long_payout_sats = self.base_funding.base_proposal.total_input_sats - self.hedge_payout_sats
-        safe_long_payout_sats = max(DUST, unsafe_long_payout_sats)
-        return UtxoSats(safe_long_payout_sats)
+        return self.payout_sats(side=Side.LONG)
+
+    @property
+    def maker_payout_sats(self) -> UtxoSats:
+        return self.payout_sats(role=Role.MAKER)
+
+    @property
+    def taker_payout_sats(self) -> UtxoSats:
+        return self.payout_sats(role=Role.TAKER)
 
     ###############
-    # Approximate unit versions of the outputs
+    # Property access to unit conversions of payouts
     ###############
     @property
     def total_payout_oracleUnits(self) -> OracleUnit:
-        return self.base_funding.base_proposal.oracle_unit_cls(self.total_payout_sats.bch * float(self.clamped_end_price_oracleUnits_per_bch))
+        return self.payout_oracleUnits()
 
     @property
     def hedge_payout_oracleUnits(self) -> OracleUnit:
-        return self.base_funding.base_proposal.oracle_unit_cls(self.hedge_payout_sats.bch * float(self.clamped_end_price_oracleUnits_per_bch))
+        return self.payout_oracleUnits(side=Side.HEDGE)
 
     @property
     def long_payout_oracleUnits(self) -> OracleUnit:
-        return self.base_funding.base_proposal.oracle_unit_cls(self.long_payout_sats.bch * float(self.clamped_end_price_oracleUnits_per_bch))
+        return self.payout_oracleUnits(side=Side.LONG)
+
+    @property
+    def maker_payout_oracleUnits(self) -> OracleUnit:
+        return self.payout_oracleUnits(role=Role.MAKER)
+
+    @property
+    def taker_payout_oracleUnits(self) -> OracleUnit:
+        return self.payout_oracleUnits(role=Role.TAKER)
 
     ###############
     # Gains - see funding class for details of fee and gain calculations
+    # TODO: These could also be parameterized with a lookup
     ###############
     @property
     def hedge_gain_sats(self) -> Sats:
@@ -447,9 +510,6 @@ class ContractRedemption:
         fee_sats = self.base_funding.fee_sats_to_long
         return Sats(payout_sats - input_sats + fee_sats)
 
-    ###############
-    # Approximate unit versions of the gains
-    ###############
     @property
     def hedge_gain_oracleUnits(self) -> OracleUnit:
         # Note that we use naive end price. This represents reality of slippage in liquidations.
@@ -472,32 +532,8 @@ class ContractRedemption:
         return 100.0 * float(self.long_gain_sats) / float(self.base_funding.base_proposal.long_input_sats)
 
     ###############
-    # Sided views on all of the above
+    # Sided views on gains
     ###############
-    @property
-    def maker_payout_sats(self) -> UtxoSats:
-        if self.base_funding.base_proposal.maker_side == Side.HEDGE:
-            return self.hedge_payout_sats
-        return self.long_payout_sats
-
-    @property
-    def taker_payout_sats(self) -> UtxoSats:
-        if self.base_funding.base_proposal.taker_side == Side.HEDGE:
-            return self.hedge_payout_sats
-        return self.long_payout_sats
-
-    @property
-    def maker_payout_oracleUnits(self) -> OracleUnit:
-        if self.base_funding.base_proposal.maker_side == Side.HEDGE:
-            return self.hedge_payout_oracleUnits
-        return self.long_payout_oracleUnits
-
-    @property
-    def taker_payout_oracleUnits(self) -> OracleUnit:
-        if self.base_funding.base_proposal.taker_side == Side.HEDGE:
-            return self.hedge_payout_oracleUnits
-        return self.long_payout_oracleUnits
-
     @property
     def maker_gain_sats(self) -> Sats:
         if self.base_funding.base_proposal.maker_side == Side.HEDGE:
