@@ -402,6 +402,10 @@ DERIVED_HEDGE_PAYOUT_ORACLE_UNITS = UsdEM2Beta(9999.999900)  # 99.99999900000 US
 DERIVED_LONG_PAYOUT_SATS = UtxoSats(18_829_333)  # 0.18829... Bch
 # Calculated as DERIVED_LONG_PAYOUT_SATS * MATURITY_PRICE / SATS_PER_BCH
 DERIVED_LONG_PAYOUT_ORACLE_UNITS = UsdEM2Beta(4142.45326)
+
+# Derived total payout sats and units
+# Calculated as hedge + long
+DERIVED_TOTAL_PAYOUT_SATS = UtxoSats(64283878)
 # Calculated as DERIVED_HEDGE_PAYOUT_ORACLE_UNITS + DERIVED_LONG_PAYOUT_ORACLE_UNITS
 DERIVED_TOTAL_PAYOUT_ORACLE_UNITS = UsdEM2Beta(14142.4532)
 
@@ -441,6 +445,9 @@ class TestNewRedemptionDerivedValues(unittest.TestCase):
         liquidation = standard_liquidation(price_oracleUnits_per_bch=BELOW_LIQUIDATING_PRICE_USDEM2_PER_BCH)
         self.assertGreater(liquidation.clamped_end_price_oracleUnits_per_bch, liquidation.naive_end_price_oracleUnits_per_bch)
 
+    def test_total_payout_sats_has_correct_value(self):
+        self.assertEqual(standard_maturation().total_payout_sats, DERIVED_TOTAL_PAYOUT_SATS)
+
     def test_hedge_payout_sats_has_correct_value(self):
         self.assertEqual(standard_maturation().hedge_payout_sats, DERIVED_HEDGE_PAYOUT_SATS)
 
@@ -552,6 +559,19 @@ class TestNewRedemptionDerivedValues(unittest.TestCase):
         self.assertEqual(c.maker_gain_percent_of_own_input, c.long_gain_percent_of_own_input)
         self.assertEqual(c.taker_gain_percent_of_own_input, c.hedge_gain_percent_of_own_input)
 
+    def test_parameterized_lookup_error_on_invalid_combinations(self):
+        maker_hedge_maturation = standard_maturation(standard_contract_funding(standard_contract_proposal(maker_side=Side.HEDGE)))
+        with self.assertRaises(ValueError):
+            maker_hedge_maturation.payout_sats(role=Role.MAKER, side=Side.LONG)
+        with self.assertRaises(ValueError):
+            maker_hedge_maturation.payout_sats(role=Role.TAKER, side=Side.HEDGE)
+
+        taker_hedge_maturation = standard_maturation(standard_contract_funding(standard_contract_proposal(maker_side=Side.LONG)))
+        with self.assertRaises(ValueError):
+            taker_hedge_maturation.payout_sats(role=Role.TAKER, side=Side.LONG)
+        with self.assertRaises(ValueError):
+            taker_hedge_maturation.payout_sats(role=Role.MAKER, side=Side.HEDGE)
+
 
 if __name__ == '__main__':
     unittest.main()
